------------------------------------------------------------------
--                                                              --
--  File:   Create_Clustered_Indexes_Scaling.SQL                --
--          Microsoft TPC-E Benchmark Kit Ver. 1.7.0-1013       --
--          Copyright Microsoft  2008, 2009                     --
--                                                              --
--  NOTE:   This file is modified by TPCE_SETUP.CMD based on    --
--          the number of processors on the system.             --
--                                                              --
------------------------------------------------------------------
USE tpce
GO
 
---
--- Set connection attributes
---
SET ANSI_NULLS ON
SET ANSI_PADDING ON
SET ANSI_WARNINGS ON
SET ARITHABORT ON
SET CONCAT_NULL_YIELDS_NULL ON
SET QUOTED_IDENTIFIER ON
SET NUMERIC_ROUNDABORT OFF
GO

-- *** ACCOUNT_PERMISSION ***
IF NOT EXISTS ( SELECT name FROM sysindexes WHERE name = 'PK_ACCOUNT_PERMISSION' )
    CREATE UNIQUE CLUSTERED INDEX PK_ACCOUNT_PERMISSION ON ACCOUNT_PERMISSION(AP_CA_ID, AP_TAX_ID)
        WITH (FILLFACTOR = 100, MAXDOP = 4)
        ON else_fg
GO

-- *** ADDRESS ***
IF NOT EXISTS ( SELECT name FROM sysindexes WHERE name = 'PK_ADDRESS' )
    CREATE UNIQUE CLUSTERED INDEX PK_ADDRESS ON ADDRESS(AD_ID)
        WITH (FILLFACTOR = 100, MAXDOP = 4)
        ON else_fg
GO

-- *** COMPANY ***
IF NOT EXISTS ( SELECT name FROM sysindexes WHERE name = 'PK_COMPANY' )
    CREATE UNIQUE CLUSTERED INDEX PK_COMPANY ON COMPANY(CO_ID)
        WITH (FILLFACTOR = 100, MAXDOP = 4)
        ON else_fg
GO

-- *** COMPANY_COMPETITOR ***
IF NOT EXISTS ( SELECT name FROM sysindexes WHERE name = 'PK_COMPANY_COMPETITOR' )
    CREATE UNIQUE CLUSTERED INDEX PK_COMPANY_COMPETITOR ON COMPANY_COMPETITOR(CP_CO_ID, CP_COMP_CO_ID, CP_IN_ID)
        WITH (FILLFACTOR = 100, MAXDOP = 4)
        ON else_fg
GO

-- *** CUSTOMER ***
IF NOT EXISTS ( SELECT name FROM sysindexes WHERE name = 'PK_CUSTOMER' )
    CREATE UNIQUE CLUSTERED INDEX PK_CUSTOMER ON CUSTOMER(C_ID)
        WITH (FILLFACTOR = 100, MAXDOP = 4)
        ON else_fg
GO

-- *** CUSTOMER_ACCOUNT ***
IF NOT EXISTS ( SELECT name FROM sysindexes WHERE name = 'PK_CUSTOMER_ACCOUNT' )
    CREATE UNIQUE CLUSTERED INDEX PK_CUSTOMER_ACCOUNT ON CUSTOMER_ACCOUNT(CA_ID)
        WITH (FILLFACTOR=80, MAXDOP = 4)
        ON else_fg
GO

-- *** CUSTOMER_TAXRATE ***
IF NOT EXISTS ( SELECT name FROM sysindexes WHERE name = 'PK_CUSTOMER_TAXRATE' )
    CREATE UNIQUE CLUSTERED INDEX PK_CUSTOMER_TAXRATE ON CUSTOMER_TAXRATE(CX_C_ID, CX_TX_ID)
        WITH (FILLFACTOR = 100, MAXDOP = 4)
        ON else_fg
GO

-- *** DAILY_MARKET ***
IF NOT EXISTS ( SELECT name FROM sysindexes WHERE name = 'PK_DAILY_MARKET' )
    CREATE UNIQUE CLUSTERED INDEX PK_DAILY_MARKET ON DAILY_MARKET(DM_S_SYMB, DM_DATE)
        WITH (FILLFACTOR = 100, MAXDOP = 4, SORT_IN_TEMPDB=ON)
        ON else_fg
GO

CHECKPOINT
GO

-- *** FINANCIAL ***
IF NOT EXISTS ( SELECT name FROM sysindexes WHERE name = 'PK_FINANCIAL' )
    CREATE UNIQUE CLUSTERED INDEX PK_FINANCIAL ON FINANCIAL(FI_CO_ID, FI_YEAR, FI_QTR)
        WITH (FILLFACTOR = 100, MAXDOP = 4)
        ON else_fg
GO

-- *** LAST_TRADE ***
IF NOT EXISTS ( SELECT name FROM sysindexes WHERE name = 'PK_LAST_TRADE' )
    CREATE UNIQUE CLUSTERED INDEX PK_LAST_TRADE ON LAST_TRADE(LT_S_SYMB)
        WITH (FILLFACTOR = 100, MAXDOP = 4)
        ON else_fg
GO

-- *** NEWS_ITEM ***
IF NOT EXISTS ( SELECT name FROM sysindexes WHERE name = 'PK_NEWS_ITEM' )
    CREATE UNIQUE CLUSTERED INDEX PK_NEWS_ITEM ON NEWS_ITEM(NI_ID)
        WITH (FILLFACTOR = 100, MAXDOP = 4, SORT_IN_TEMPDB=ON)
        ON else_fg
GO

CHECKPOINT
GO

-- *** NEWS_XREF ***
IF NOT EXISTS ( SELECT name FROM sysindexes WHERE name = 'PK_NEWS_XREF' )
    CREATE UNIQUE CLUSTERED INDEX PK_NEWS_XREF ON NEWS_XREF(NX_CO_ID, NX_NI_ID)
        WITH (FILLFACTOR = 100, MAXDOP = 4)
        ON else_fg
GO

-- *** SECURITY ***
IF NOT EXISTS ( SELECT name FROM sysindexes WHERE name = 'PK_SECURITY' )
    CREATE UNIQUE CLUSTERED INDEX PK_SECURITY ON SECURITY(S_SYMB)
        WITH (FILLFACTOR = 100, MAXDOP = 4)
        ON else_fg
GO

-- *** WATCH_ITEM ***
IF NOT EXISTS ( SELECT name FROM sysindexes WHERE name = 'PK_WATCH_ITEM' )
    CREATE UNIQUE CLUSTERED INDEX PK_WATCH_ITEM ON WATCH_ITEM(WI_WL_ID, WI_S_SYMB)
        WITH (FILLFACTOR = 100, MAXDOP = 4)
        ON else_fg
GO
 
-- *** WATCH_LIST ***
IF NOT EXISTS ( SELECT name FROM sysindexes WHERE name = 'PK_WATCH_LIST' )
    CREATE UNIQUE CLUSTERED INDEX PK_WATCH_LIST ON WATCH_LIST(WL_ID)
        WITH (FILLFACTOR = 100, MAXDOP = 4)
        ON else_fg
GO
