------------------------------------------------------------------
--                                                              --
--  File:   MarketWatch.SQL                                     --
--          Microsoft TPC-E Benchmark Kit Ver. 1.7.0-1013       --
--         Copyright Microsoft  2008, 2009                      --
--                                                              --
------------------------------------------------------------------
USE tpce
GO

IF EXISTS(  SELECT  name
            FROM    sysobjects
            WHERE   name    = 'MarketWatchFrame1' AND
                    type    = 'P')
DROP PROCEDURE  MarketWatchFrame1
GO

-- MarketWatchFrame1 is responsible for retrieving 
-- the current price of each symbol on the list 
-- and computing the average percentage of change 
-- in price over the list. 
CREATE PROCEDURE    MarketWatchFrame1
                        @acct_id        IDENT_T,    /* IN customer account ID */ 
                        @industry_name  char(50),   /* IN industry name */ 
                        @starting_co_id IDENT_T,    /* IN starting company ID */
                        @ending_co_id   IDENT_T,    /* IN ending company ID */
                        @cust_id        IDENT_T,    /* IN customer ID */
                        @start_date     datetime    /* IN start date */
AS
BEGIN
    SET TRANSACTION ISOLATION LEVEL READ COMMITTED

    BEGIN TRANSACTION

    DECLARE -- local variables
            @old_mkt_cap    numeric(17,2),
            @new_mkt_cap    numeric(17,2),
            @pct_change     BALANCE_T,
            @symbol         varchar(15),
            @new_price      BALANCE_T,
            @s_num_out      S_COUNT_T,
            @old_price      BALANCE_T
		
    IF (@cust_id <> 0)
        DECLARE Stock_List CURSOR LOCAL FAST_FORWARD
                FOR SELECT  WI_S_SYMB
                    FROM    WATCH_ITEM,
                            WATCH_LIST
                    WHERE   WI_WL_ID    = WL_ID AND
                            WL_C_ID     = @cust_id
    ELSE
        IF (@acct_id <> 0)
            DECLARE Stock_List CURSOR LOCAL FAST_FORWARD
                    FOR SELECT  HS_S_SYMB
                        FROM    HOLDING_SUMMARY
                        WHERE   HS_CA_ID = @acct_id
        ELSE
            IF (@industry_name <> '')
                DECLARE Stock_List CURSOR LOCAL FAST_FORWARD
                        FOR SELECT  S_SYMB
                            FROM    INDUSTRY
                                    JOIN COMPANY  ON CO_IN_ID = IN_ID
                                    JOIN SECURITY ON S_CO_ID  = CO_ID
                            WHERE   IN_NAME     = @industry_name AND
                                    CO_ID BETWEEN @starting_co_id AND 
                                                  @ending_co_id
                            ORDER   BY CO_ID
                            OPTION  (LOOP JOIN, FORCE ORDER)
            ELSE
                RETURN (5)	-- return bad input data code

    SELECT  @old_mkt_cap    = 0.0,
            @new_mkt_cap    = 0.0 

    OPEN Stock_List 

    FETCH FROM Stock_List INTO @symbol 
	
    WHILE (@@FETCH_STATUS = 0)
        BEGIN
            SELECT  @new_price  = LT_PRICE 
            FROM    LAST_TRADE 
            WHERE   LT_S_SYMB   = @symbol 

            SELECT  @s_num_out  = S_NUM_OUT 
            FROM    SECURITY 
            WHERE   S_SYMB      = @symbol 

            SELECT  @old_price  = DM_CLOSE 
            FROM    DAILY_MARKET 
            WHERE   DM_S_SYMB   = @symbol AND
                    DM_DATE     = @start_date
            
            SELECT  @old_mkt_cap    = @old_mkt_cap + (@s_num_out * @old_price),
                    @new_mkt_cap    = @new_mkt_cap + (@s_num_out * @new_price)
		
            -- Fetch again
            FETCH FROM Stock_List INTO @symbol
        END
	
    CLOSE       Stock_List
    DEALLOCATE  Stock_List

    IF (@old_mkt_cap <> 0)
        SELECT  100 * ((@new_mkt_cap / @old_mkt_cap) - 1)
    ELSE
        SELECT	NULL

	COMMIT TRANSACTION	
END
